==> apache-camel-2.20.3-src.zip: apache-camel-2.20.3/components/camel-drill/src/main/java/org/apache/camel/component/drill/DrillComponent.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.drill;

import java.util.Map;

import org.apache.camel.CamelContext;
import org.apache.camel.Endpoint;
import org.apache.camel.impl.UriEndpointComponent;

/**
 * Represents the component that manages {@link DrillEndpoint}. It holds the
 * list of named direct endpoints.
 */
public class DrillComponent extends UriEndpointComponent {

    public DrillComponent() {
        super(DrillEndpoint.class);
    }

    public DrillComponent(final CamelContext context) {
        super(context, DrillEndpoint.class);
    }

    @Override
    protected Endpoint createEndpoint(String uri, String remaining, Map<String, Object> parameters) throws Exception {
        DrillEndpoint endpoint = new DrillEndpoint(uri, this);
        setProperties(endpoint, parameters);
        endpoint.setHost(remaining);

        return endpoint;
    }
}

==> apache-camel-4.10.8-src.zip: apache-camel-4.10.8/components/camel-drill/src/main/java/org/apache/camel/component/drill/DrillComponent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.drill;

import java.util.Map;

import org.apache.camel.CamelContext;
import org.apache.camel.Endpoint;
import org.apache.camel.spi.annotations.Component;
import org.apache.camel.support.DefaultComponent;

/**
 * Represents the component that manages {@link DrillEndpoint}. It holds the list of named direct endpoints.
 */
@Component("drill")
public class DrillComponent extends DefaultComponent {

    public DrillComponent() {
    }

    public DrillComponent(final CamelContext context) {
        super(context);
    }

    @Override
    protected Endpoint createEndpoint(String uri, String remaining, Map<String, Object> parameters) throws Exception {
        DrillEndpoint endpoint = new DrillEndpoint(uri, this);
        setProperties(endpoint, parameters);
        endpoint.setHost(remaining);

        return endpoint;
    }
}
